@@ -102,7 +102,7 @@ dfsane <- function(par, fn, method=2, control=list(), ...) {
 ######################################
 #     MAIN LOOP:  Iteration begins
 ######################################
-    flag <- 0 # for case when tol is already ok initially and while loop is skipped
+    flag <- NULL # for case when tol is already ok initially and while loop is skipped
     while (normF/sqrt(n) > tol & iter <= maxit) {
  
     	# Control of steplength
@@ -161,6 +161,11 @@ dfsane <- function(par, fn, method=2, control=list(), ...) {
 
     	}   # End of main loop
 
+     if (is.null(flag)) {
+        warning("convergence tolerance satisified at intial parameter values.")
+	flag <- 0
+	}
+
     conv <-
      if (flag==0) {
        if (normF/sqrt(n) <= tol) 
